@@ -8,6 +8,7 @@
 !      2002/03/25  ݹ  ⥸塼̾ѹ
 !      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
 !      2002/10/07  ݹ  , ̺ɸʬɲ
+!      2005/04/23  ݹ  ڥȥϥ⥸塼ɲ
 !
 !         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
 !
@@ -17,8 +18,10 @@ module wa_module
   use wa_base_module
   use w_deriv_module
   use w_integral_module
+  use w_spectrum_module
   use wa_deriv_module
   use wa_integral_module
+  use wa_spectrum_module
 
   private
 
@@ -62,6 +65,26 @@ module wa_module
   public ya_AvrLon_xya, a_AvrLon_xa           ! ʿ    
   public xa_AvrLat_xya, a_AvrLat_ya           ! ʿ    
 
+  public nma_EnergyFromStreamfunction_wa      ! ͥ륮ڥȥ
+                                              ! (ʿȿ n, Ӿȿ m )
+  public na_EnergyFromStreamfunction_wa       ! ͥ륮ڥȥ
+                                              ! (ʿȿ n )
+  public nma_EnstrophyFromStreamfunction_wa   ! 󥹥ȥեڥȥ
+                                              ! (ʿȿ n, Ӿȿ m )
+  public na_EnstrophyFromStreamfunction_wa    ! 󥹥ȥեڥȥ
+                                              !  (ʿȿ n )
+  public wa_spectrum_VMiss                    ! »
+
+  public nm_EnergyFromStreamfunction_w      ! ͥ륮ڥȥ           
+                                            ! (ʿȿ n, Ӿȿ m )
+  public n_EnergyFromStreamfunction_w       ! ͥ륮ڥȥ
+                                            ! (ʿȿ n ) 
+  public nm_EnstrophyFromStreamfunction_w   ! 󥹥ȥեڥȥ     
+                                            ! (ʿȿ n, Ӿȿ m )
+  public n_EnstrophyFromStreamfunction_w    ! 󥹥ȥեڥȥ  
+                                            !  (ʿȿ n )
+  public w_spectrum_VMiss                   ! »
+
 contains
   subroutine wa_Initial(n_in,i_in,j_in,k_in)
 
